@@ -46,14 +46,13 @@ Detailed information and updates: http://geobaza.ru/.
 __copyright__ = "Copyright 2014, CN-Software Ltd."
 
 __license__ = "New-style BSD"
-__version__ = "1.0.5.14.05"
+__version__ = "1.0.6.14.12"
 __email__ = "support@cn-software.com"
 __status__ = "Production"
 
 import os
 import socket
 import struct
-import decimal
 import xml.etree.cElementTree as etree
 from time import time
 from datetime import datetime as dt
@@ -67,15 +66,19 @@ FILE_PATH = '%s/data/geobaza.dat' % os.path.normpath(os.path.dirname(__file__))
 NO_CACHE = 0
 MEMORY_CACHE = 1
 
+
 class GeobazaException(Exception):
     pass
 
+
 class GeobazaIPException(GeobazaException):
     pass
 
+
 class Headers(Bunch):
     pass
 
+
 class Serializer(object):
     def to_xml(self):
         """Returns XML"""
@@ -95,6 +98,7 @@ class Serializer(object):
         """Returns pretty printed JSON"""
         return json.dumps(self.as_dict(), sort_keys=True, indent=4)
 
+
 class Binary(object):
     """Proxy for working with binary files"""
 
@@ -103,9 +107,11 @@ class Binary(object):
         data = self.read(bytes)
         return struct.unpack_from(fmt, data)[0]
 
+
 class BinaryFile(Binary, file):
     __new__ = singleton_init
 
+
 class BinaryBlob(Binary):
     __new__ = singleton_init
 
@@ -132,6 +138,7 @@ class BinaryBlob(Binary):
         self.offset = offset
         return data
 
+
 class Language(object):
     def __init__(self, id, name):
         self.id = id
@@ -140,6 +147,7 @@ class Language(object):
     def __repr__(self):
         return '<Language: %s>' % self.name.encode('utf-8')
 
+
 class Languages(object):
     _languages = {
         'aa': u'Afar',
@@ -341,11 +349,13 @@ class Languages(object):
             raise GeobazaException('Language with ISO ID %s does not exists!' % id)
         return Language(id, lang)
 
+
 class LatLon(object):
     def __init__(self, lat=None, lon=None):
         self.latitude = lat
         self.longitude = lon
 
+
 class Geography(Serializer):
     def __init__(self, **kwargs):
         for k, v in kwargs.iteritems():
@@ -363,9 +373,11 @@ class Geography(Serializer):
         """Returns self as python dictionary"""
         return {'center': {'latitude': self.center.latitude, 'longitude': self.center.longitude}}
 
+
 class AbstractObject(object):
     pass
 
+
 class GeobazaObject(AbstractObject, Serializer):
     COUNTRY = 'country'
     REGION = 'region'
@@ -385,13 +397,13 @@ class GeobazaObject(AbstractObject, Serializer):
                 self.population = None
 
         def translation(data):
-            RAW_MAP = {
+            raw_map = {
                 'official': (0, 'name_official'),
                 'alt': (1, 'name'),
             }
 
             self.translations = []
-            for type, (priority, key) in RAW_MAP.iteritems():
+            for type, (priority, key) in raw_map.iteritems():
                 obj = Bunch(type=type)
                 for lang, name in data.get(key).iteritems():
                     obj[lang.lower()] = name
@@ -439,23 +451,23 @@ class GeobazaObject(AbstractObject, Serializer):
 
     def as_xml(self):
         """Returns self as xml.etree.cElementTree.Element"""
-        object = etree.Element('object')
-        object.set('type', self.type)
-        object.set('id', to_str(self.id))
+        obj = etree.Element('object')
+        obj.set('type', self.type)
+        obj.set('id', to_str(self.id))
         if self.parent:
-            object.set('parent', to_str(self.parent.id))
+            obj.set('parent', to_str(self.parent.id))
         if self.child:
-            object.set('child', to_str(self.child.id))
+            obj.set('child', to_str(self.child.id))
 
-        name = etree.SubElement(object, 'name')
+        name = etree.SubElement(obj, 'name')
         name.text = self.name
-        iso_id = etree.SubElement(object, 'iso-id')
+        iso_id = etree.SubElement(obj, 'iso-id')
         iso_id.text = to_str(self.iso_id)
 
-        object.append(self.geography.as_xml())
-        population = etree.SubElement(object, 'population')
+        obj.append(self.geography.as_xml())
+        population = etree.SubElement(obj, 'population')
         population.text = to_str(self.population)
-        translations = etree.SubElement(object, 'translations')
+        translations = etree.SubElement(obj, 'translations')
         for item in self.translations:
             group = etree.SubElement(translations, 'group')
             group.set('type', item.type)
@@ -464,20 +476,21 @@ class GeobazaObject(AbstractObject, Serializer):
                     translation = etree.SubElement(group, 'item')
                     translation.set('language', key)
                     translation.text = value
-        return object
+        return obj
 
     def as_dict(self, attrs=[]):
         """Returns self as python dictionary"""
-        object = {'type': self.type, 'name': self.name, 'iso_id': to_str(self.iso_id), 'id': self.id}
+        obj = {'type': self.type, 'name': self.name, 'iso_id': to_str(self.iso_id), 'id': self.id}
         if self.parent:
-            object['parent'] = self.parent.id
+            obj['parent'] = self.parent.id
         if self.child:
-            object['child'] = self.child.id
+            obj['child'] = self.child.id
+
+        obj['geography'] = self.geography.as_dict()
+        obj['population'] = to_str(self.population)
+        obj['translations'] = self.translations
+        return obj
 
-        object['geography'] = self.geography.as_dict()
-        object['population'] = to_str(self.population)
-        object['translations'] = self.translations
-        return object
 
 class Region(GeobazaObject):
     def __init__(self, data):
@@ -501,12 +514,13 @@ class Region(GeobazaObject):
         return xml
 
     def as_dict(self):
-        object = super(Region, self).as_dict()
+        obj = super(Region, self).as_dict()
         language = None
         if self.language:
             language = {'name': self.language.name, 'id': self.language.id}
-        object['language'] = language
-        return object
+        obj['language'] = language
+        return obj
+
 
 class Country(Region):
     def __init__(self, data):
@@ -530,19 +544,22 @@ class Country(Region):
         return xml
 
     def as_dict(self):
-        object = super(Region, self).as_dict()
-        object['tld'] = self.tld
-        return object
+        obj = super(Region, self).as_dict()
+        obj['tld'] = self.tld
+        return obj
+
 
 class Locality(GeobazaObject):
     pass
 
+
 class SpecialRange(AbstractObject, Serializer):
     """
     Class for special IPv4 addresses ranges
 
     See: http://www.iana.org/assignments/ipv4-address-space/ipv4-address-space.xml
     """
+
     def __init__(self, data):
         self.type = GeobazaObject.SPECIAL
         self.name = data.get('special', None)
@@ -565,6 +582,7 @@ class SpecialRange(AbstractObject, Serializer):
     def as_dict(self):
         return {'type': self.type, 'name': to_str(self.name)}
 
+
 class Geobaza(Serializer):
     REPR_OUTPUT_SIZE = 2
 
@@ -734,21 +752,22 @@ class Geobaza(Serializer):
 
     def as_dict(self):
         # Headers
-        object = {
-            'api_version': self.headers.api_version,
-            'release': self.headers.release,
-            'build_timestamp': self.headers.build_timestamp,
-            'build_date': to_str(self.headers.build_date),
-            'lite': to_str(self.headers.lite),
-            'query_timestamp': time(),
-            'ip': self.ip,
-            'is_special': to_str(self.is_special),
-        }
+        obj = dict(
+            api_version=self.headers.api_version,
+            release=self.headers.release,
+            build_timestamp=self.headers.build_timestamp,
+            build_date=to_str(self.headers.build_date),
+            lite=to_str(self.headers.lite),
+            query_timestamp=time(),
+            ip=self.ip,
+            is_special=to_str(self.is_special)
+        )
 
         # Objects
-        object['objects'] = [item.as_dict() for item in self]
+        obj['objects'] = [item.as_dict() for item in self]
+
+        return obj
 
-        return object
 
 class GeobazaQuery(object):
     _level = []
@@ -766,7 +785,7 @@ class GeobazaQuery(object):
         # Headers
         headers = json.loads(self.f.read(self.f.unpack(2, '!H')))
         headers['build_date'] = dt.fromtimestamp(headers['build_timestamp'])
-        headers['lite'] = headers.has_key('lite')
+        headers['lite'] = 'lite' in headers
         headers['release'] = headers['release'].strip()
         self.headers = Headers(**headers)
 
@@ -783,12 +802,18 @@ class GeobazaQuery(object):
 
         self.offset = self.f.tell()
 
-    def _ip2long(self, ip):
+    @staticmethod
+    def ip2long(ip):
         try:
             return struct.unpack_from('!L', socket.inet_aton(ip))[0]
         except socket.error:
             raise GeobazaIPException('Given IP-adress is invalid!')
 
+    @staticmethod
+    def validate_ip(ip):
+        if not validate_ip(ip):
+            raise GeobazaIPException('Given IP-adress is invalid!')
+
     def _get_json(self, offset, path=False):
         json_str = []
         while offset:
@@ -812,13 +837,13 @@ class GeobazaQuery(object):
         return self.f.unpack(2, '!H') & 0xffff
 
     def _get(self, ip, path=False):
-        self._validate_ip(ip)
+        GeobazaQuery.validate_ip(ip)
         offset = self.offset
-        ip_int = self._ip2long(ip)
+        ip_int = GeobazaQuery.ip2long(ip)
         shift = 32
         for i in xrange(len(self._level)):
             shift -= self._level[i]
-            index = ((ip_int >> shift)) & ((1 << self._level[i]) - 1)
+            index = (ip_int >> shift) & ((1 << self._level[i]) - 1)
             tell = offset + index * 4
             self.f.seek(tell, 0)
             unpack = self.f.unpack(4, '!L')
@@ -826,10 +851,6 @@ class GeobazaQuery(object):
             if offset & 0x80000000:
                 return self._get_json(offset, path=path)
 
-    def _validate_ip(self, ip):
-        if not validate_ip(ip):
-            raise GeobazaIPException('Given IP-adress is invalid!')
-
     def get(self, ip):
         json_str = self._get(ip)
         if json_str:
@@ -851,6 +872,7 @@ class GeobazaQuery(object):
         if json_str:
             return json.loads(json_str)
 
+
 def lookup(ip):
     try:
         geobaza = GeobazaQuery()
@@ -858,6 +880,7 @@ def lookup(ip):
     except GeobazaException:
         pass
 
+
 def lookup_xml(ip, pretty=False):
     geobaza = lookup(ip)
     if geobaza:
@@ -865,6 +888,7 @@ def lookup_xml(ip, pretty=False):
             return geobaza.to_pretty_xml()
         return geobaza.to_xml()
 
+
 def lookup_json(ip, pretty=False):
     geobaza = lookup(ip)
     if geobaza:
